@@ -1,6 +1,6 @@
 use core::fmt::Debug;
 
-use bonsaidb::core::schema::{Collection, CollectionName, Schema, Schematic};
+use bonsaidb::core::schema::{Collection, CollectionName, Qualified, Schema, Schematic};
 
 #[test]
 fn core() {
